@@ -5,11 +5,15 @@ err() {
     exit 1
 }
 
+make_doc() {
+    echo "'touch man/git-$1.md && make man/git-$1.{1,html}'"
+}
+
 check_bash_script() {
     local cmd="git-$1"
 
     test -f "bin/$cmd" \
-        || err "Bin/$cmd does not exist"
+        || err "bin/$cmd does not exist"
 
     test -x "bin/$cmd" \
         || err "Run 'chmod +x bin/$cmd' to make it executable"
@@ -19,14 +23,32 @@ check_bash_script() {
         || err "Start git-$1 with '#!/usr/bin/env bash'"
 }
 
+check_git_extras_cmd_list() {
+    local whitelist=('extras')
+    for cmd in ${whitelist[*]}; do
+        test "$1" == "$cmd" && return
+    done
+
+    grep "\- \*\*git\-$1(1)\*\*" man/git-extras.md >/dev/null \
+        || err "Add git-$1 in the list of commands in man/git-extras.md via $(make_doc "$1")"
+}
+
+check_man_page_index() {
+    grep "git\-$1(1) git\-$1" man/index.txt >/dev/null \
+        || err "Add git-$1 to index.txt via $(make_doc "$1")"
+}
+
 check_documentation() {
     local cmd="git-$1"
-    test -f "man/$cmd.md" || err "create man/$cmd.md"
+    test -f "man/$cmd.md" || err "man/$cmd.md is required for bin/$cmd"
 
     if [ ! -f "man/$cmd.1" ] || [ ! -f "man/$cmd.html" ]
     then
-        err "Run 'make docs' to create man/$cmd.1 and man/$cmd.html"
+        err "Create man/$cmd.1 and man/$cmd.html via $(make_doc "$1")"
     fi
+
+    check_git_extras_cmd_list "$@"
+    check_man_page_index "$@"
 }
 
 check_Commands_page() {
@@ -64,10 +86,8 @@ test $# == 0 && usage
 
 for name in "$@"; do
     name=${name#git-}
-    [[ "$name" == "rscp" || "$name" == "line-summary" ]] && echo "Skip command $name" \
-        && continue
+    [[ "$name" == "rscp" ]] && continue
     check "$name"
 done
 
 echo 'All done'
-exit 0
